@@ -14,7 +14,11 @@ pub(crate) fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
 }
 
 fn run(matches: &ArgMatches) -> Result<()> {
-    let is_local = Some("local") == matches.value_of("scope");
+    let subcommand = matches
+        .subcommand_matches("lint")
+        .and_then(|matches| matches.subcommand_matches("generate"))
+        .unwrap();
+    let is_local = Some("local") == subcommand.value_of("scope");
     let current_dir = current_dir()?;
     let mut vcs = get_vcs(is_local, &current_dir)?;
     let input_toml = external::read_toml(current_dir)?;
